import pyttsx3

finglish_dict = {
    "آ": "Aa", "ا": "a", "ب": "b", "پ": "p", "ت": "t", "ث": "s", "ج": "j", "چ": "ch", "ح": "h", "خ": "kh", 
    "د": "d", "ذ": "z", "ر": "r", "ز": "z", "ژ": "zh", "س": "s", "ش": "sh", "ص": "s", "ض": "z", 
    "ط": "t", "ظ": "z", "ع": "a", "غ": "gh", "ف": "f", "ق": "gh", "ک": "k", "گ": "g", "ل": "l", 
    "م": "m", "ن": "n", "و": "v", "ه": "h", "ی": "y"
}

vowels = ['ا', 'و', 'ی','آ', 'و']

def farsi_to_finglish_with_vowels(text):
    result = ""
    prev_char = ""
    for char in text:
        if char in finglish_dict:
            if prev_char in vowels and char in vowels:
                result += finglish_dict[char]
            else:
                result += finglish_dict.get(char, char)
        elif char == "َ":
            result += "a"
        elif char == "ُ":
            result += "o"
        elif char == "ِ":
            result += "e"
        elif char == "ْ":
            result += ""
        else:
            result += char
        prev_char = char
    return result



from setuptools import setup, find_packages

setup(
    name="parstalk",
    version="1.3",
    packages=find_packages(),
    install_requires=["pyttsx3"],
    author="Mohammadjavad Ghaderi",
    author_email="Mohammadjavadd.ronaldo@gmail.com",
    description="Convert Farsi text to finglish with vowel detection and play sound",
    long_description=open("README.md", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
